﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using ThinkGeo.MapSuite.WebEdition;
using ThinkGeo.MapSuite.Core;

namespace ExtendMapSuiteExploringLayersWeb
{
    public partial class _Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                Map1.MapUnit = GeographyUnit.DecimalDegree;
                // Set the full extent and the background color
                Map1.CurrentExtent = ExtentHelper.GetDrawingExtent(new RectangleShape(-180.0, 83.0, 180.0, -90.0), (float)Map1.Width.Value, (float)Map1.Height.Value);
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

                // Add the worldLayer to the MapEngine
                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(MapPath(@"~/App_Data/Countries02.shp"), ShapeFileReadWriteMode.ReadOnly);
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.County1;
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                Map1.StaticOverlay.Layers.Add("WorldLayer", worldLayer);
            }
        }

        protected void btnMultiGeoRasterLayer_Click(object sender, EventArgs e)
        {
            Layer worldLayer = Map1.StaticOverlay.Layers["WorldLayer"];
            Map1.StaticOverlay.Layers.Clear();
            Map1.StaticOverlay.Layers.Add("WorldLayer", worldLayer);

            MultiGeoRasterLayer.BuildReferenceFile(MapPath(@"~/App_Data/RasterImage/refrenceFile.txt"),MapPath(@"~/App_Data/RasterImage"));
            MultiGeoRasterLayer multiGeoRasterLayer = new MultiGeoRasterLayer(MapPath(@"~/App_Data/RasterImage/refrenceFile.txt"));
            Map1.StaticOverlay.Layers.Add("MultiGeoRasterLayer", multiGeoRasterLayer);
        }

        protected void btnWaterMarkLayer_Click(object sender, EventArgs e)
        {
            Layer worldLayer = Map1.StaticOverlay.Layers["WorldLayer"];
            Map1.StaticOverlay.Layers.Clear();
            Map1.StaticOverlay.Layers.Add("WorldLayer", worldLayer);

            // Add the watermarkLayer to the MapEngine
            WatermarkAdornmentLayer watermarkLayer = new WatermarkAdornmentLayer();
            Map1.StaticOverlay.Layers.Add("WatermarkLayer", watermarkLayer);

        }

        protected void btnMiniMapLayer_Click(object sender, EventArgs e)
        {
            // We need to set it to Single Tile otherwise as the tiles are drawn at the same time, 
            // it will have some cross threading issue
            Map1.StaticOverlay.TileType = TileType.SingleTile;

            Layer worldLayer = Map1.StaticOverlay.Layers["WorldLayer"];
            Map1.StaticOverlay.Layers.Clear();
            Map1.StaticOverlay.Layers.Add("WorldLayer", worldLayer);

            // Add the watermarkLayer to the MapEngine
            MiniMapAdornmentLayer miniMapLayer = new MiniMapAdornmentLayer();
            miniMapLayer.Location = AdornmentLocation.LowerLeft;

            miniMapLayer.Layers.Add(new BackgroundLayer(Map1.MapBackground.BackgroundBrush));
            for (int i = 0; i < Map1.StaticOverlay.Layers.Count; i++)
            {
                miniMapLayer.Layers.Add(Map1.StaticOverlay.Layers[i]);
            }

            Map1.StaticOverlay.Layers.Add(miniMapLayer);
        }

        protected void btnMapShapeLayer_Click(object sender, EventArgs e)
        {
            ShapeFileFeatureLayer worldLayer = (ShapeFileFeatureLayer)Map1.StaticOverlay.Layers["WorldLayer"];
            Map1.StaticOverlay.Layers.Clear();
            Map1.StaticOverlay.Layers.Add("WorldLayer", worldLayer);

            // Add the mapShapeLayer to the MapEngine
            MapShapeLayer mapShapeLayer = new MapShapeLayer();

            MapShape mapShape1 = new MapShape(new Feature(-104, 42));
            mapShape1.ZoomLevels.ZoomLevel01.DefaultPointStyle = new PointStyle(new GeoImage(MapPath(@"~/App_Data/Image/Cargo Plane.png")));
            mapShape1.ZoomLevels.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            mapShapeLayer.MapShapes.Add("1", mapShape1);

            MapShape mapShape2 = new MapShape(new Feature(104, 39));
            mapShape2.ZoomLevels.ZoomLevel01.DefaultPointStyle = new PointStyle(new GeoImage(MapPath(@"~/App_Data/Image/China.png")));
            mapShape2.ZoomLevels.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            mapShapeLayer.MapShapes.Add("2", mapShape2);

            worldLayer.Open();
            Feature feature3 = worldLayer.QueryTools.GetFeatureById("222", ReturningColumnsType.AllColumns);
            MapShape mapShape3 = new MapShape(feature3);
            mapShape3.ZoomLevels.ZoomLevel01.DefaultAreaStyle = AreaStyles.Forest1;
            mapShape3.ZoomLevels.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            mapShapeLayer.MapShapes.Add("3", mapShape3);

            BaseShape shape = new PointShape(-71, -52).GetShortestLineTo(new PointShape(38, 8), GeographyUnit.DecimalDegree);
            MapShape mapShape4 = new MapShape(new Feature(shape));
            mapShape4.ZoomLevels.ZoomLevel01.DefaultLineStyle = LineStyles.ContestedBorder2;
            mapShape4.ZoomLevels.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            mapShapeLayer.MapShapes.Add("4", mapShape4);

            Map1.StaticOverlay.Layers.Add("MapShapeLayer", mapShapeLayer);

        }
    }
}
