﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.Core;

namespace ExtendMapSuiteExploringLayersWeb
{
    public class MapShapeLayer : Layer
    {
        private Dictionary<string, MapShape> mapShapes;

        public MapShapeLayer()
        {
            this.mapShapes = new Dictionary<string, MapShape>();
        }

        // Here is where you place all of your map shapes.
        public Dictionary<string, MapShape> MapShapes
        {
            get { return mapShapes; }
        }

        // This is a required overload of the Layer.  As you can see we simply
        // loop through all of our map shapes and then choose the correct zoom level.
        // After that, the zoom level class takes care of the heavy lifiting.  You
        // have to love how easy this framework is to re-use.
        protected override void DrawCore(GeoCanvas canvas, Collection<SimpleCandidate> labelsInAllLayers)
        {
            foreach (string mapShapeKey in mapShapes.Keys)
            {
                MapShape mapShape = mapShapes[mapShapeKey];
                ZoomLevel currentZoomLevel = mapShape.ZoomLevels.GetZoomLevelForDrawing(canvas.CurrentWorldExtent, canvas.Width, canvas.MapUnit);
                if (currentZoomLevel != null)
                {
                    if (canvas.CurrentWorldExtent.Intersects(mapShape.Feature.GetBoundingBox()))
                    {
                        currentZoomLevel.Draw(canvas, new Feature[] { mapShape.Feature }, new Collection<SimpleCandidate>(), labelsInAllLayers);
                    }
                }
            }
        }
    }
}
